# cmdpxl: a totally practical command-line image editor
![ezgif com-gif-maker (2)](https://user-images.githubusercontent.com/30610197/128618252-d00100dd-6ca4-4089-b7a1-d7790b99a1cc.gif)

## Features
cmdpxl has many exciting functionalities, including
- Editing pixels *one at a time*!
- Saving images!
- An undo function!
- A fill tool!
- Cool image filters!

## Installation

Install the package with:
```sh
pip install cmdpxl
```

## Usage

Run with `cmdpxl`.

You can also specify the file path and resolution: for example, to create a new image that is 20px wide and 10px tall you can use

```
cmdpxl -f new_image.png -res 20,10
```
To get the full list of options:

```
$ cmdpxl --help
Usage: main.py [OPTIONS]

Options:
  -f, --filepath PATH      Path for the file you want to open
  -res, --resolution TEXT  Image height and width separated by a comma, e.g.
                           20,10 for a 20x10 image. Note that no spaces can be
                           used.
  --help                   Show this message and exit.
```

## Examples
Here are some images that have been created with `cmdpxl`. If you have any images you'd like to share, please open a pull request or create an issue.

![image](https://user-images.githubusercontent.com/30610197/130501861-2ea41d6f-5568-47d9-b7e4-764c9136c979.png)
![image](https://user-images.githubusercontent.com/30610197/130502042-744f269e-9ffc-4089-81bb-5b58a15fa6db.png)
![image](https://user-images.githubusercontent.com/30610197/130501975-88423180-de64-49ff-afc5-dd670d959e9c.png)
![image](https://user-images.githubusercontent.com/30610197/130503771-4ae14006-494b-405c-9657-1eacd013c13f.png)




## Why?
Good question.
